@@ -1,9 +1,13 @@
 <?php
+/* Path for SquirrelMail required files. */
+define('SM_PATH','../../');
+require_once(SM_PATH . 'include/validate.php');
+require_once(SM_PATH . 'functions/imap.php');
+require_once(SM_PATH . 'functions/plugin.php');
+require_once(SM_PATH . 'functions/page_header.php');
+require_once(SM_PATH . 'functions/html.php');
 
-chdir('..');
-include_once('../src/validate.php');
-include_once('../functions/imap.php');
-require_once('../plugins/bayesspam/config.php');
+require_once(SM_PATH . 'plugins/bayesspam/config.php');
 
 if (!isset($_REQUEST)) {
 	$_REQUEST['bayes_type']=$HTTP_GET_VARS['bayes_type'];
