@@ -1,13 +1,15 @@
 <?php /* Modified at 1 places by ri_once */ ?>
 <?php /* 'php' Added by ri_once */
 require_once('DB.php');
-require_once('../plugins/bayesspam/bayesspam_functions.php');
-require_once('../plugins/bayesspam/bayesspam_filter.php');
+require_once(SM_PATH . 'plugins/bayesspam/bayesspam_functions.php');
+require_once(SM_PATH . 'plugins/bayesspam/bayesspam_filter.php');
 
 global $bayesdbhandle, $bayesdbuser, $bayesdbpass, $bayesdbhost, $bayesdbport, $bayesdbname, $bayes_username, $username, $bayes_message_id, $bayes_allow_db_nuke; 
-global $bayesspam_ignore_folders, $bayes_max_size, $bayes_cache_days, $bayes_message_store_days, $bayes_was_cached, $bayesspam_scan_size, $bayes_ignore_size;
+global $bayesspam_ignore_folders, $bayes_max_size, $bayes_cache_days, $bayes_message_store_days, $bayes_was_cached, $bayesspam_scan_size;
 global $bayes_default_scan_size, $bayes_autorebuild_timeout, $bayesdbtype, $bayesspam_tokens, $bayesspam_update_tokens, $bayesspam_spam_occurences;
 global $bayesspam_nonspam_occurences, $bayesspam_cached_occurences, $bayesspam_inboxonly, $token_display_string, $token_html_dislay_string;
+global $bayesspam_do_stats, $bayesspam_do_user_stats, $bayesspam_do_global_stats, $bayesspam_do_server_stats, $bayesspam_do_uncertain_filtering;
+global $bayesspam_uncertain_folder;
 
 if(!isset($_SESSION['bayesspam_corpus'])) {
 	session_register('bayesspam_corpus');
@@ -56,26 +58,37 @@ $GLOBALS['bayes_default_scan_size'] = 65536; // 64 KB
 //    will be used when calculating the score
 $GLOBALS['bayes_max_size'] = 131072; // 128 KB
 
-// Ignore Size
-//    BayesSpam will totally ignore messages larger than this
-$GLOBALS['bayes_ignore_size'] = 2097152; // 2 MB
-
 // Cache Days
 //    How many days to cache message scores for. Longer improves
 //    performance. Shorter gives more accurate scores.
 //    Note that users do have a link to recalculate the score.
-$GLOBALS['bayes_cache_days'] = 10;
+$GLOBALS['bayes_cache_days'] = 30;
 
 // Message Store Days
 //    How many days to cache knowledge of whether a message was
 //    added to the spam or nonspam DB.
-$GLOBALS['bayes_message_store_days'] = 10;
+$GLOBALS['bayes_message_store_days'] = 30;
 
 // Corpus Autorebuild Timeout
 //    How many minutes to require between automatic rebuilds of the
 //    spam Corpus. Set to 0 to always allow an automatic rebuild.
 $GLOBALS['bayes_autorebuild_timeout'] = 15;
 
+// Stats Tracking
+//    Whether or not to enable stats tracking options.
+//    If using stats tracking, Message Store Days and Cache Days
+//    should be set to at least 2 weeks to make the stats somewhat
+//    accurate.
+$GLOBALS['bayesspam_do_stats'] = TRUE;
+
+// Serverwide Stats Tracking (NOT YET IMPLEMENTED)
+//    Whether or not to enable global stats tracking. (Requires stats options to be enabled)
+$GLOBALS['bayesspam_do_server_stats'] = TRUE;
+
+// Submit Global To Global Stats Database (NOT YET IMPLEMENTED)
+//    Whether or not to enable global stats tracking. (Requires stats options to be enabled)
+$GLOBALS['bayesspam_do_global_stats'] = TRUE;
+
 // NOTHING ELSE TO ADJUST
 
 if ($GLOBALS['bayes_granularity'] == 'user') {
