@@ -1,11 +1,11 @@
 <?php
-chdir ('..');
-require_once('../src/validate.php');
-require_once('../functions/page_header.php');
-require_once('../functions/imap.php');
-require_once('../src/load_prefs.php');
-require_once('../plugins/bayesspam/config.php');
-
+define('SM_PATH','../../');
+require_once(SM_PATH . 'include/validate.php');
+require_once(SM_PATH . 'functions/imap.php');
+require_once(SM_PATH . 'functions/plugin.php');
+require_once(SM_PATH . 'functions/page_header.php');
+require_once(SM_PATH . 'functions/html.php');
+require_once(SM_PATH . 'plugins/bayesspam/config.php');
 
 $key = $_COOKIE['key'];
 $onetimepad = $_SESSION['onetimepad'];
@@ -56,8 +56,18 @@ elseif ($_REQUEST['action'] == 'showprob')
 	setPref($GLOBALS['data_dir'], $GLOBALS['username'], 'bayesspam_show_prob', 1);
 elseif ($_REQUEST['action'] == 'noshowprob')
 	setPref($GLOBALS['data_dir'], $GLOBALS['username'], 'bayesspam_show_prob', '');
+elseif ($_REQUEST['action'] == 'dostats')
+	setPref($GLOBALS['data_dir'], $GLOBALS['username'], 'bayesspam_do_user_stats', 1);
+elseif ($_REQUEST['action'] == 'nodostats')
+	setPref($GLOBALS['data_dir'], $GLOBALS['username'], 'bayesspam_do_user_stats', '');
+elseif ($_REQUEST['action'] == 'douncertain')
+	setPref($GLOBALS['data_dir'], $GLOBALS['username'], 'bayesspam_do_uncertain_filtering', 1);
+elseif ($_REQUEST['action'] == 'nodouncertain')
+	setPref($GLOBALS['data_dir'], $GLOBALS['username'], 'bayesspam_do_uncertain_filtering', '');
 elseif ($_REQUEST['action'] == 'folder' && isset($_REQUEST['folder']))
 	setPref($GLOBALS['data_dir'], $GLOBALS['username'], 'bayesspam_folder', $_REQUEST['folder']);
+elseif ($_REQUEST['action'] == 'uncertainfolder' && isset($_REQUEST['uncertainfolder']))
+	setPref($GLOBALS['data_dir'], $GLOBALS['username'], 'bayesspam_uncertain_folder', $_REQUEST['uncertainfolder']);
 elseif ($_REQUEST['action'] == 'set_scan_size' && isset($_REQUEST['scan_size'])) {
 	if ($_REQUEST['scan_size'] > $GLOBALS['bayes_max_size']) {
 		$_REQUEST['scan_size'] = $GLOBALS['bayes_max_size'];
@@ -135,6 +145,17 @@ bayesspam_load();
 	  <?PHP }
 	  ?></td>
 	</tr>
+<? if ($GLOBALS['bayesspam_filtering_enabled']) { ?>
+    <tr>
+	  <td align=right>Filtering Uncertain Messages is:</td>
+	  <td><?PHP if ($GLOBALS['bayesspam_do_uncertain_filtering']) { 
+	  ?><font color=darkgreen>Enabled</font> (<a href="options.php?action=nodouncertain">Disable it</a>)
+	  <?PHP } else {
+	  ?><font color=red>Disabled</font> (<a href="options.php?action=douncertain">Enable it</a>)
+	  <?PHP }
+	  ?></td>
+	</tr>
+<? } ?>
     <tr>
 	  <td align=right valign=top>Spam Deletion is:
 	  </td>
@@ -175,6 +196,16 @@ bayesspam_load();
 	  <?PHP }
 	  ?></td>
 	</tr>
+    <tr>
+	  <td align=right valign=top>Stats Tracking is:
+	  </td>
+	  <td valign=top><?PHP if ($GLOBALS['bayesspam_do_user_stats']) { 
+	  ?><font color=darkgreen>Enabled</font> (<a href="options.php?action=nodostats">Disable it</a>)
+	  <?PHP } else {
+	  ?><font color=red>Disabled</font> (<a href="options.php?action=dostats">Enable it</a>)
+	  <?PHP }
+	  ?></td>
+	</tr>
 	<tr><td>&nbsp;</td></tr>
 	<tr>
 		<td align=right>Bytes of message to scan:<br><font size=-1>Maximum: <? echo $GLOBALS['bayes_max_size']; ?></font></td>
@@ -209,6 +240,32 @@ bayesspam_load();
 	  </td></form>
 	</tr>
 	<tr><td>&nbsp;</td></tr>
+<? if ($GLOBALS['bayesspam_do_uncertain_filtering']) { ?>
+	<tr>
+	  <td align=right>Folder To Filter Uncertain Messages Into:</td>
+	  <form method=post action=options.php><td>
+	    <select name=uncertainfolder>
+<?
+        for ($i = 0; $i < count($boxes); $i++) {
+            if (! in_array('noselect', $boxes[$i]['flags'])) {
+                $box = $boxes[$i]['unformatted'];
+                $box2 = str_replace(' ', '&nbsp;', $boxes[$i]['formatted']);
+                if (isset($GLOBALS['bayesspam_uncertain_folder']) &&
+                    $GLOBALS['bayesspam_uncertain_folder'] == $box)
+                echo "<OPTION VALUE=\"$box\" SELECTED>$box2</option>";
+                else
+                echo "<OPTION VALUE=\"$box\">$box2</option>";
+            }
+        }
+
+?>
+	    </select></td><td>
+	    <input type=hidden name=action value=uncertainfolder>
+	    <input type=submit value="Save">
+	  </td></form>
+	</tr>
+	<tr><td>&nbsp;</td></tr>
+<? } ?>
     <tr>
           <td align=right valign=top>Check Inbox Only:
           </td>
@@ -268,7 +325,60 @@ href="options.php?action=inboxonly">Enable it</a>)
 	  <td align=center colspan=2>&nbsp;<P>
 		<b>Spam Database Stats:</b><br>
 <table>
-<tr><td align=right>NonSpam Emails Submitted:</td>
+<tr><td align=right>Total Mail Filtered:</td>
+<td align=right>
+<?
+$res = $GLOBALS['bayesdbhandle']->query("SELECT TotalMessages FROM stats WHERE UserName='".$GLOBALS['bayes_username']."'");
+if (!DB::isError($res)) {
+	$row = $res->fetchRow();
+	echo $row['TotalMessages'];
+} else {
+	echo $res->getDebugInfo();
+}
+?>
+</td>
+</tr>
+<tr><td align=right>Total Filtered as Spam:</td>
+<td align=right>
+<?
+$res = $GLOBALS['bayesdbhandle']->query("SELECT SpamMessages FROM stats WHERE UserName='".$GLOBALS['bayes_username']."'");
+if (!DB::isError($res)) {
+	$row = $res->fetchRow();
+	echo $row['SpamMessages'];
+} else {
+	echo $res->getDebugInfo();
+}
+?>
+</td>
+</tr>
+<tr><td align=right>Total Filtered as NonSpam:</td>
+<td align=right>
+<?
+$res = $GLOBALS['bayesdbhandle']->query("SELECT HamMessages FROM stats WHERE UserName='".$GLOBALS['bayes_username']."'");
+if (!DB::isError($res)) {
+	$row = $res->fetchRow();
+	echo $row['HamMessages'];
+} else {
+	echo $res->getDebugInfo();
+}
+?>
+</td>
+</tr>
+<tr><td align=right>Overall Accuracy (Based on Corrections):</td>
+<td align=right>
+<?
+$res = $GLOBALS['bayesdbhandle']->query("SELECT ( ( ( TotalMessages - FalseNegatives - ( UnsureMessages / 2  )  - ( FalsePositives * 2  )  ) / TotalMessages ) * 100 ) AS Accuracy FROM stats
+WHERE UserName='".$GLOBALS['bayes_username']."'");
+if (!DB::isError($res)) {
+	$row = $res->fetchRow();
+	echo $row['Accuracy']."%";
+} else {
+	echo $res->getDebugInfo();
+}
+?>
+</td>
+</tr>
+<tr><td align=right>NonSpam Emails in Corpus:</td>
 <td align=right>
 <?
 $res = $GLOBALS['bayesdbhandle']->query("SELECT nonspamCount FROM users WHERE UserName='".$GLOBALS['bayes_username']."'");
@@ -281,7 +391,7 @@ if (!DB::isError($res)) {
 ?>
 </td>
 </tr>
-<tr><td align=right>Spam Emails Submitted:</td>
+<tr><td align=right>Spam Emails in Corpus:</td>
 <td align=right>
 <?
 $res = $GLOBALS['bayesdbhandle']->query("SELECT spamCount FROM users WHERE UserName='".$GLOBALS['bayes_username']."'");
