@@ -1,5 +1,5 @@
 <?php
-require_once('../plugins/bayesspam/config.php');
+require_once(SM_PATH . 'plugins/bayesspam/config.php');
 
 /* Initialize the plugin */
 function squirrelmail_plugin_init_bayesspam() {
@@ -54,6 +54,9 @@ function bayesspam_load() {
 	$GLOBALS['bayesspam_show_prob'] = getPref($GLOBALS['data_dir'], $GLOBALS['username'], 'bayesspam_show_prob');
 	$GLOBALS['bayesspam_scan_size'] = getPref($GLOBALS['data_dir'], $GLOBALS['username'], 'bayesspam_scan_size');
 	$GLOBALS['bayesspam_inboxonly'] = getPref($GLOBALS['data_dir'], $GLOBALS['username'], 'bayesspam_inboxonly');
+	$GLOBALS['bayesspam_do_user_stats'] = getPref($GLOBALS['data_dir'], $GLOBALS['username'], 'bayesspam_do_user_stats');
+	$GLOBALS['bayesspam_do_uncertain_filtering'] = getPref($GLOBALS['data_dir'], $GLOBALS['username'], 'bayesspam_do_uncertain_filtering');
+	$GLOBALS['bayesspam_uncertain_folder'] = getPref($GLOBALS['data_dir'], $GLOBALS['username'], 'bayesspam_uncertain_folder');
 
 	if ($GLOBALS['bayesspam_scan_size'] == '') {
 		$GLOBALS['bayesspam_scan_size'] = $GLOBALS['bayes_default_scan_size'];
@@ -148,13 +151,17 @@ EOL;
 			$s .=   '</b></a></td>' . "\n";
 		} else {
 			$s .=   '<TD align=right valign=top width=20%><b>BayesSpam Probability:&nbsp;&nbsp;</b></TD>'."\n";
-			$s .=   '<TD align=left valign=top width=80% colspan=2>'. number_format($is_spam*100,2).'%';
+			$s .=   '<TD align=left valign=top width=80% colspan=2>';
+			if ($do_popup_link) {
+				$s .= '<a href="javascript:do_bayesspam_popup()">';
+			}
+			$s .= '<span title="'.$GLOBALS['token_display_string'].'">'. number_format($is_spam*100,2).'%';
 			if ($GLOBALS['bayes_was_cached']) {
 				$s .= ' (Cached)';
 			} else {
 				$s .= ' (Calculated)';
 			}
-			$s .=   '</td>' . "\n";
+			$s .=   '</span></a></td>' . "\n";
 		}
 		$s .= '</TR>';
 	
